# Changelog

All notable changes to this project will be documented in this file.

## [0.7.2] - 2024-05-22

### Fixed

- Serialize field with UniqueIds as string

## [0.7.1] - 2024-05-22

### Fixed

- Use str to serialize UniqueId

## [0.7.0] - 2024-05-22

### Fixed

- Serialize UniuqeId as str

## [0.6.5] - 2024-05-15

### Documentation

- Update readme

## [0.6.3] - 2024-05-14

### Miscellaneous Tasks

- Rename project to karp-lex-types

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## Latest Changes

## 0.6.0

- Update pydantic to V2.
- Repo move to [spraakbanken/karp-lex-core](https://github/spraakbanken/karp-lex-core) from [spraakbanken/karp-backend](https://github/spraakbanken/karp-backend)

## 0.5.0

- Cleaning up & documenting. PR [#226](https://github.com/spraakbanken/karp-backend/pull/226) by [@kod-kristoff](https://github.com/kod-kristoff).
- changed: use camelCase in all api interactions. PR [#225](https://github.com/spraakbanken/karp-backend/pull/225) by [@kod-kristoff](https://github.com/kod-kristoff).

## 0.4.0

### Added

- Added Generic Commands. PR [#224](https://github.com/spraakbanken/karp-backend/pull/224) by [@kod-kristoff](https://github.com/kod-kristoff).

- Added cmdtype tags. PR [#223](https://github.com/spraakbanken/karp-backend/pull/223) by [@kod-kristoff](https://github.com/kod-kristoff).

## 0.3.2

- Repo move to [spraakbanken/karp-backend](https://github/spraakbanken/karp-backend) from [spraakbanken/karp-lex-core](https://github/spraakbanken/karp-lex-core)

## 0.1.0

- Created project.
